@@ -7,11 +7,11 @@ COLOURS = {
     "white": "#FFFFFF",
     "grey": "#C1C7D0",
     "red": "#FF5630",
-    "yellow": "FFAB00",
-    "green": "36B37E",
-    "purple": "6554C0",
-    "black": "091E42",
-    "light_grey": "EBECF0",
+    "yellow": "#FFAB00",
+    "green": "#36B37E",
+    "purple": "#6554C0",
+    "black": "#091E42",
+    "light_grey": "#EBECF0",
 }
 
 
